==> haskell-tasty-inspection-testing-0.2.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-5AsS1mWZDKHDnTPsCu9eYC
key:                  tasty-inspection-testing-0.2.1-5AsS1mWZDKHDnTPsCu9eYC
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  e9faeea2a4fefca4f5c177ebda1ba24f
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-5AsS1mWZDKHDnTPsCu9eYC
depends:
    base-4.17.2.1 ghc-9.4.8
    inspection-testing-0.6.1-7z12puupsSO26u2d8pLl44
    tasty-1.5-DKPyyhrT6bQLAKRwWi9DQv template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-inspection-testing-0.2.1-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-BG8wpUl88WS8dchKWaJHqx
key:                  tasty-inspection-testing-0.2.1-BG8wpUl88WS8dchKWaJHqx
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  577e775496875cb27645f85766ced848
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-BG8wpUl88WS8dchKWaJHqx
depends:
    base-4.17.2.1 ghc-9.4.8
    inspection-testing-0.6.1-7z12puupsSO26u2d8pLl44
    tasty-1.5-FRQtZsdenVIBoQGCChJ79f template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
